@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: TestDnsNameServer.cc 10041 2018-01-20 05:02:45Z dwm $
+// @(#) $Id: TestDnsNameServer.cc 10560 2020-04-24 23:01:10Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018
 //  All rights reserved.
@@ -50,7 +50,7 @@ extern "C" {
 #include "DwmUnitAssert.hh"
 #include "DwmDnsNameServer.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.1.0/classes/tests/TestDnsNameServer.cc 10041 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.1.1/classes/tests/TestDnsNameServer.cc 10560 $");
 
 using namespace std;
 using namespace Dwm;
@@ -164,7 +164,7 @@ void TestGooglePTR()
       Dns::RRDataPTR  *ptr = answer.Data<Dns::RRDataPTR>();
       UnitAssert(answer.Name() == "8.8.8.8.in-addr.arpa");
       if (UnitAssert(ptr != nullptr)) {
-        UnitAssert(ptr->Ptr().find("google.com") != string::npos);
+        UnitAssert(ptr->Ptr().find("dns.google") != string::npos);
       }
     }
   }
